lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [4945] Recognize version macros for EDG compilers


From: Greg Chicares
Subject: [lmi-commits] [4945] Recognize version macros for EDG compilers
Date: Thu, 13 May 2010 01:08:35 +0000

Revision: 4945
          http://svn.sv.gnu.org/viewvc/?view=rev&root=lmi&revision=4945
Author:   chicares
Date:     2010-05-13 01:08:34 +0000 (Thu, 13 May 2010)
Log Message:
-----------
Recognize version macros for EDG compilers

Modified Paths:
--------------
    lmi/trunk/config.hpp
    lmi/trunk/test_coding_rules.cpp

Modified: lmi/trunk/config.hpp
===================================================================
--- lmi/trunk/config.hpp        2010-05-10 17:15:38 UTC (rev 4944)
+++ lmi/trunk/config.hpp        2010-05-13 01:08:34 UTC (rev 4945)
@@ -89,6 +89,8 @@
 #endif // __GNUC__
 
 #if defined __COMO__
+#   define LMI_COMO_VERSION __COMO_VERSION__
+#   define LMI_EDG_VERSION  __EDG_VERSION__
 //  09 Oct 2004 17:04:46 -0700 email from <address@hidden>
 //  suggests this method to detect whether MinGW is the underlying C
 //  compiler. Because it requires including some standard header

Modified: lmi/trunk/test_coding_rules.cpp
===================================================================
--- lmi/trunk/test_coding_rules.cpp     2010-05-10 17:15:38 UTC (rev 4944)
+++ lmi/trunk/test_coding_rules.cpp     2010-05-13 01:08:34 UTC (rev 4945)
@@ -767,8 +767,10 @@
         ,"_LIBC"
         ,"__BIG_ENDIAN"
         ,"__BYTE_ORDER"
     // Compiler specific: como.
         ,"__COMO__"
+        ,"__COMO_VERSION__"
+        ,"__EDG_VERSION__"
     // Compiler specific: borland.
         ,"_CatcherPTR"
         ,"__BORLANDC__"
@@ -767,8 +767,10 @@
         ,"__BIG_ENDIAN"
         ,"__BYTE_ORDER"
-    // Compiler specific: como.
+    // Compiler specific: como including EDG.
         ,"__COMO__"




reply via email to

[Prev in Thread] Current Thread [Next in Thread]